package com.goldenwater.yjjt.service.impl;

import java.util.List;
import java.util.Map;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.yjjt.domain.YjjtStation;
import com.goldenwater.yjjt.mapper.YjjtStationMapper;
import com.goldenwater.yjjt.service.IYjjtStationService;

/**
 * 引江济太站点Service业务层处理
 */
@Service
public class YjjtStationServiceImpl implements IYjjtStationService
{
    @Autowired
    private YjjtStationMapper yjjtStationMapper;

    @Override
    public YjjtStation selectYjjtStationById(Long id)
    {
        return yjjtStationMapper.selectYjjtStationById(id);
    }

    @Override
    public YjjtStation selectByStcd(String stcd)
    {
        return yjjtStationMapper.selectByStcd(stcd);
    }

    @Override
    public List<YjjtStation> selectYjjtStationList(YjjtStation station)
    {
        return yjjtStationMapper.selectYjjtStationList(station);
    }

    @Override
    public int insertYjjtStation(YjjtStation station)
    {
        return yjjtStationMapper.insertYjjtStation(station);
    }

    @Override
    public int updateYjjtStation(YjjtStation station)
    {
        return yjjtStationMapper.updateYjjtStation(station);
    }

    @Override
    public int deleteYjjtStationByIds(Long[] ids)
    {
        return yjjtStationMapper.deleteYjjtStationByIds(ids);
    }

    @Override
    public int deleteYjjtStationById(Long id)
    {
        return yjjtStationMapper.deleteYjjtStationById(id);
    }
}
